==> haskell-websockets-0.12.5.3-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: websockets
version: 0.12.5.3
id: websockets-0.12.5.3-35e4c7bj26J5SRNWLXLSLJ
key: websockets-0.12.5.3-35e4c7bj26J5SRNWLXLSLJ
license: BSD-3-Clause
copyright: (c) 2010-2011 Siniša Biđin
           (c) 2011-2018 Jasper Van der Jeugt
           (c) 2011 Steffen Schuldenzucker
           (c) 2011 Alex Lang
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Siniša Biđin <sinisa@bidin.cc>
        Jasper Van der Jeugt <m@jaspervdj.be>
        Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
        Alex Lang <lang@tsurucapital.com>
stability: experimental
homepage: http://jaspervdj.be/websockets
synopsis: A sensible and clean way to write WebSocket-capable servers in Haskell.
description:
    This library allows you to write WebSocket-capable servers.
    .
    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>
    .
    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>
    .
    See also:
    .
    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>
    .
    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>
category: Network
abi: dfdf2f55c4af49643a494124a4b2680e
exposed: True
exposed-modules:
    Network.WebSockets Network.WebSockets.Connection
    Network.WebSockets.Extensions Network.WebSockets.Stream
hidden-modules: Network.WebSockets.Client
                Network.WebSockets.Connection.Options
                Network.WebSockets.Extensions.Description
                Network.WebSockets.Extensions.PermessageDeflate
                Network.WebSockets.Extensions.StrictUnicode Network.WebSockets.Http
                Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
                Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
                Network.WebSockets.Server Network.WebSockets.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/websockets-0.12.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/websockets-0.12.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/websockets-0.12.5.3
hs-libraries: HSwebsockets-0.12.5.3-35e4c7bj26J5SRNWLXLSLJ
depends:
    SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv
    attoparsec-0.13.2.2-DdvIu9rGyq0BlJd07CKvqt base-4.12.0.0
    base64-bytestring-1.0.0.2-Isuu0DM5i6LOS2qIIf24 binary-0.8.6.0
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    containers-0.6.0.1 entropy-0.4.1.4-23NMAjgKyCo3F1ZCvvDJOh
    network-2.8.0.0-3PgnnHopFNTASnxFyU0kPh
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    streaming-commons-0.2.1.1-JDbyOCUboytep6iMDEhoZ text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html: /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-websockets-0.12.5.3-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: websockets
version: 0.12.5.3
id: websockets-0.12.5.3-2r1mhnUp9bnJRthSZet1gV
key: websockets-0.12.5.3-2r1mhnUp9bnJRthSZet1gV
license: BSD-3-Clause
copyright: (c) 2010-2011 Siniša Biđin
           (c) 2011-2018 Jasper Van der Jeugt
           (c) 2011 Steffen Schuldenzucker
           (c) 2011 Alex Lang
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Siniša Biđin <sinisa@bidin.cc>
        Jasper Van der Jeugt <m@jaspervdj.be>
        Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
        Alex Lang <lang@tsurucapital.com>
stability: experimental
homepage: http://jaspervdj.be/websockets
synopsis: A sensible and clean way to write WebSocket-capable servers in Haskell.
description:
    This library allows you to write WebSocket-capable servers.
    .
    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>
    .
    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>
    .
    See also:
    .
    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>
    .
    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>
category: Network
abi: e4ea6cff57e940da3c52975a465a850a
exposed: True
exposed-modules:
    Network.WebSockets Network.WebSockets.Connection
    Network.WebSockets.Extensions Network.WebSockets.Stream
hidden-modules: Network.WebSockets.Client
                Network.WebSockets.Connection.Options
                Network.WebSockets.Extensions.Description
                Network.WebSockets.Extensions.PermessageDeflate
                Network.WebSockets.Extensions.StrictUnicode Network.WebSockets.Http
                Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
                Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
                Network.WebSockets.Server Network.WebSockets.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/websockets-0.12.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/websockets-0.12.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/websockets-0.12.5.3
hs-libraries: HSwebsockets-0.12.5.3-2r1mhnUp9bnJRthSZet1gV
depends:
    SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    base64-bytestring-1.0.0.2-C0hiEzqCknwIpHHXqmcpJo binary-0.8.6.0
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    containers-0.6.0.1 entropy-0.4.1.4-23NMAjgKyCo3F1ZCvvDJOh
    network-2.8.0.0-HTKosw7lwpaCVnkz1nc19d
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    streaming-commons-0.2.1.1-FltEP5lCx0137LYmTxSGHQ text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html: /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
